@@ -20,7 +20,6 @@
 #endif
 
 #include "eog-file-chooser.h"
-#include "eog-config-keys.h"
 #include "eog-pixbuf-util.h"
 
 #include <stdlib.h>
@@ -29,14 +28,13 @@
 #include <glib/gi18n.h>
 #include <gio/gio.h>
 #include <gtk/gtk.h>
-#include <gconf/gconf-client.h>
 
 /* We must define GNOME_DESKTOP_USE_UNSTABLE_API to be able
    to use GnomeDesktopThumbnail */
 #ifndef GNOME_DESKTOP_USE_UNSTABLE_API
 #define GNOME_DESKTOP_USE_UNSTABLE_API
 #endif
-#include <libgnomeui/gnome-desktop-thumbnail.h>
+#include <libgnome-desktop/gnome-desktop-thumbnail.h>
 
 static char *last_dir[] = { NULL, NULL, NULL, NULL };
 
@@ -142,40 +140,17 @@ save_response_cb (GtkDialog *dlg, gint id, gpointer data)
 	}
 }
 
-static void
-eog_file_chooser_add_filter (EogFileChooser *chooser)
+static GSList*
+_eog_file_chooser_prepare_save_file_filter (GtkFileFilter *all_img_filter)
 {
-	GSList *it;
-	GSList *formats;
- 	GtkFileFilter *all_file_filter;
-	GtkFileFilter *all_img_filter;
-	GtkFileFilter *filter;
 	GSList *filters = NULL;
+	GSList *formats = NULL;
+	GSList *it;
+	GtkFileFilter *filter;
 	gchar **mime_types, **pattern, *tmp;
 	int i;
-	GtkFileChooserAction action;
 
-	action = gtk_file_chooser_get_action (GTK_FILE_CHOOSER (chooser));
-
-	if (action != GTK_FILE_CHOOSER_ACTION_SAVE && action != GTK_FILE_CHOOSER_ACTION_OPEN) {
-		return;
-	}
-
-	/* All Files Filter */
-	all_file_filter = gtk_file_filter_new ();
-	gtk_file_filter_set_name (all_file_filter, _("All Files"));
-	gtk_file_filter_add_pattern (all_file_filter, "*");
-
-	/* All Image Filter */
-	all_img_filter = gtk_file_filter_new ();
-	gtk_file_filter_set_name (all_img_filter, _("All Images"));
-
-	if (action == GTK_FILE_CHOOSER_ACTION_SAVE) {
-		formats = eog_pixbuf_get_savable_formats ();
-	}
-	else {
-		formats = gdk_pixbuf_get_formats ();
-	}
+	formats = eog_pixbuf_get_savable_formats ();
 
 	/* Image filters */
 	for (it = formats; it != NULL; it = it->next) {
@@ -222,6 +197,39 @@ eog_file_chooser_add_filter (EogFileChooser *chooser)
 	}
 	g_slist_free (formats);
 
+	return filters;
+}
+static void
+eog_file_chooser_add_filter (EogFileChooser *chooser)
+{
+	GSList *it;
+ 	GtkFileFilter *all_file_filter;
+	GtkFileFilter *all_img_filter;
+	GSList *filters = NULL;
+	GtkFileChooserAction action;
+
+	action = gtk_file_chooser_get_action (GTK_FILE_CHOOSER (chooser));
+
+	if (action != GTK_FILE_CHOOSER_ACTION_SAVE && action != GTK_FILE_CHOOSER_ACTION_OPEN) {
+		return;
+	}
+
+	/* All Files Filter */
+	all_file_filter = gtk_file_filter_new ();
+	gtk_file_filter_set_name (all_file_filter, _("All files"));
+	gtk_file_filter_add_pattern (all_file_filter, "*");
+
+	/* All Image Filter */
+	all_img_filter = gtk_file_filter_new ();
+	gtk_file_filter_set_name (all_img_filter, _("Supported image files"));
+
+	if (action == GTK_FILE_CHOOSER_ACTION_SAVE) {
+		filters = _eog_file_chooser_prepare_save_file_filter(all_img_filter);
+	}
+	else {
+		gtk_file_filter_add_pixbuf_formats(all_img_filter);
+	}
+
 	/* Add filter to filechooser */
 	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (chooser), all_file_filter);
 	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (chooser), all_img_filter);
